@@ -13,7 +13,7 @@
 #include "jobtrackermodel.h"
 #include "jobtrackersearchwidget.h"
 
-#include <AkonadiWidgets/controlgui.h>
+#include <Akonadi/ControlGui>
 
 #include <QApplication>
 #include <QClipboard>
@@ -25,7 +25,7 @@
 #include <QTreeView>
 #include <QVBoxLayout>
 
-class JobTrackerWidget::Private
+class JobTrackerWidgetPrivate
 {
 public:
     JobTrackerModel *model = nullptr;
@@ -36,7 +36,7 @@ public:
 
 JobTrackerWidget::JobTrackerWidget(const char *name, QWidget *parent, const QString &checkboxText)
     : QWidget(parent)
-    , d(new Private)
+    , d(new JobTrackerWidgetPrivate)
 {
     d->model = new JobTrackerModel(name, this);
 
@@ -77,10 +77,7 @@ JobTrackerWidget::JobTrackerWidget(const char *name, QWidget *parent, const QStr
     Akonadi::ControlGui::widgetNeedsAkonadi(this);
 }
 
-JobTrackerWidget::~JobTrackerWidget()
-{
-    delete d;
-}
+JobTrackerWidget::~JobTrackerWidget() = default;
 
 void JobTrackerWidget::selectOnlyErrorChanged(bool state)
 {
